@@ -1,8 +1,13 @@
+import warnings
+warnings.filterwarnings("ignore", ".*could not open display.*", Warning)
+warnings.filterwarnings("ignore", ".*g_object_unref.*", Warning)
+
 import logging
 import optparse
 
 import dbus
 import gobject
+import gio
 import pynotify
 
 import udiskie.device
@@ -48,12 +53,15 @@ class AutoMounter:
                         self.log.error('failed to mount device %s: %s' % (device,
                                                                           dbus_err))
                         return
-	
+
                     mount_paths = ', '.join(device.mount_paths())
-	            pynotify.Notification('Device mounted',
-	                                  '%s mounted on %s' % (device.device_file(),
-	                                                        mount_paths),
-	                                  'drive-removable-media').show()
+                    try:
+                        pynotify.Notification('Device mounted',
+                                              '%s mounted on %s' % (device.device_file(),
+                                                                    mount_paths),
+                                              'drive-removable-media').show()
+                    except gio.Error:
+                        pass
             finally:
                 self._store_device_state(device)
 
